﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using WorkoutSharing.ViewModels;
using WorkoutSharing.DomainLogic;

namespace WorkoutSharing.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            CreateWorkoutData();

            return View();
        }

        public ActionResult About()
        {
            ViewBag.Message = "Your application description page.";

            return View();
        }

        public ActionResult Contact()
        {
            ViewBag.Message = "Your contact page.";

            return View();
        }

        public JsonResult GetWorkout()
        {
            var athlets = (List<Athlete>)Session["ATHLETS"];

            return Json(athlets, JsonRequestBehavior.AllowGet);
        }

        [HttpPost]
        public JsonResult SaveTweet(string username, string workoutType, DateTime date, double rate, double distance, double duration, string comments)
        {
            var athlets = (List<Athlete>)Session["ATHLETS"] ?? new List<Athlete>();
            var athlet = athlets.Find(x => x.Username == "@"+username);

            if (workoutType == "Bike")
            {
                athlet.AddWorkout(new BikeWorkout(WorkoutType.Outdoor, distance, date, TimeSpan.FromMinutes(duration), rate, comments));
            }
            else
            {
                athlet.AddWorkout(new Workout(date, TimeSpan.FromMinutes(duration), rate, comments));
            }

            Session["ATHLETS"] = athlets;

            return Json(athlets, JsonRequestBehavior.AllowGet);
        }

        private void CreateWorkoutData()
        {
            var athlets = (List<Athlete>)Session["ATHLETS"];
            if (athlets == null)
            {
                athlets = new List<Athlete>();
                var rnd = new Random(78);

                var athlete1 = new Athlete("@jasyhss", Gender.Male, rnd.Next(18, 45), rnd.Next(110, 210), rnd.Next(5, 7) + rnd.Next(1, 7) * (1 / 100.0));
                athlete1.AddWorkout(
                    new BikeWorkout(WorkoutType.Outdoor, 8.21, DateTime.Now, TimeSpan.FromMinutes(67), 106, "Test drove the new bike around Greenlake!"),
                    new Workout(DateTime.Now.AddDays(-2), new TimeSpan(0, 14, 3), 124, "Single leg squats FTW!"));
                athlets.Add(athlete1);


                var athlete2 = new Athlete("@erwfsdfs", Gender.Female, rnd.Next(18, 45), rnd.Next(110, 210), rnd.Next(5, 7) + rnd.Next(1, 7) * (1 / 100.0));
                athlete2.AddWorkout(
                    new BikeWorkout(WorkoutType.Outdoor, 8.21, DateTime.Now, TimeSpan.FromMinutes(67), 113, "Learning how to bike in the streets :O"),
                    new Workout(DateTime.Now.AddDays(-1), new TimeSpan(1, 2, 43), 132, "500 lb squat day. #gainz"));
                athlets.Add(athlete2);

                var athlete3 = new Athlete("@rtsfsdfs", Gender.Female, rnd.Next(18, 45), rnd.Next(110, 210), rnd.Next(5, 7) + rnd.Next(1, 7) * (1 / 100.0));
                athlete3.AddWorkout(
                    new DistanceWorkout(.99, DateTime.Now.AddDays(-6), TimeSpan.FromMinutes(20), 125, "Meh. Light jog on treadmill..."),
                    new Workout(DateTime.Now.AddDays(-4), new TimeSpan(1, 2, 43), 132, "500 lb squat day. #training"));

                athlets.Add(athlete3);

                Session["ATHLETS"] = athlets;
            }
        }
    }
}