﻿-- <Migration ID="bfcd7f0f-0368-453e-abb0-0d3a323f6bb2" />
GO

PRINT N'Creating [dbo].[Workouts]'
GO
CREATE TABLE [dbo].[Workouts]
(
[Id] [int] NOT NULL IDENTITY(1, 1),
[Date] [datetime] NOT NULL,
[Duration] [int] NOT NULL,
[AverageHeartRate] [float] NOT NULL,
[Distance] [float] NOT NULL,
[Pace] [float] NOT NULL,
[Type] [int] NOT NULL,
[Notes] [nvarchar] (max) NULL,
[AthleteId] [int] NOT NULL
)
GO
PRINT N'Creating primary key [PK_dbo.Workouts] on [dbo].[Workouts]'
GO
ALTER TABLE [dbo].[Workouts] ADD CONSTRAINT [PK_dbo.Workouts] PRIMARY KEY CLUSTERED  ([Id])
GO
PRINT N'Creating [dbo].[Athletes]'
GO
CREATE TABLE [dbo].[Athletes]
(
[Id] [int] NOT NULL IDENTITY(1, 1),
[Username] [nvarchar] (max) NULL,
[Gender] [int] NOT NULL,
[Age] [int] NOT NULL,
[Weight] [float] NOT NULL,
[Height] [float] NOT NULL,
[BasalMetabolicRate] [float] NOT NULL
)
GO
PRINT N'Creating primary key [PK_dbo.Athletes] on [dbo].[Athletes]'
GO
ALTER TABLE [dbo].[Athletes] ADD CONSTRAINT [PK_dbo.Athletes] PRIMARY KEY CLUSTERED  ([Id])
GO
PRINT N'Creating [dbo].[GetCaloriesBurned]'
GO

CREATE FUNCTION  [dbo].[GetCaloriesBurned] 
(
	@workoutId int
)
RETURNS decimal
AS
BEGIN
	-- Declare the return variable here
	DECLARE @calories decimal,
			@athleteId int,
			@gender int,
			@age int,
			@weight decimal,
			@averageHeartRate decimal,
			@duration int

	select @athleteId = AthleteId, @averageHeartRate = AverageHeartRate from dbo.Workouts where Id = @workoutId
	select @gender = Gender, @age = Age from dbo.Athletes where Id = @athleteId

	if @gender = 1 -- Male
	begin
		set @calories = (-55.0969 + (0.6309 * @averageHeartRate)
						   + (0.1988 * @weight) + (0.2017 * @age) / 4.184)
						   * @duration;
	end
	else -- Female
	begin
		set @calories = (-20.4022 + (0.4472 * @averageHeartRate)
						   + (0.1263 * @weight) + (0.074 * @age) / 4.184)
						   *  @duration;
	end


	return @calories

END
GO
PRINT N'Creating [dbo].[Gender]'
GO
CREATE TABLE [dbo].[Gender]
(
[Id] [int] NOT NULL,
[Name] [nvarchar] (50) NULL
)
GO
PRINT N'Creating primary key [PK_Gender] on [dbo].[Gender]'
GO
ALTER TABLE [dbo].[Gender] ADD CONSTRAINT [PK_Gender] PRIMARY KEY CLUSTERED  ([Id])
GO
PRINT N'Creating [dbo].[WorkoutType]'
GO
CREATE TABLE [dbo].[WorkoutType]
(
[Id] [int] NOT NULL,
[Name] [nvarchar] (50) NULL
)
GO
PRINT N'Creating primary key [PK_WorkoutType] on [dbo].[WorkoutType]'
GO
ALTER TABLE [dbo].[WorkoutType] ADD CONSTRAINT [PK_WorkoutType] PRIMARY KEY CLUSTERED  ([Id])
GO
PRINT N'Adding foreign keys to [dbo].[Workouts]'
GO
ALTER TABLE [dbo].[Workouts] ADD CONSTRAINT [FK_dbo.Workouts_dbo.Athletes_AthleteId] FOREIGN KEY ([AthleteId]) REFERENCES [dbo].[Athletes] ([Id]) ON DELETE CASCADE
GO
ALTER TABLE [dbo].[Workouts] ADD CONSTRAINT [FK_Workouts_Type] FOREIGN KEY ([Type]) REFERENCES [dbo].[WorkoutType] ([Id])
GO
PRINT N'Adding foreign keys to [dbo].[Athletes]'
GO
ALTER TABLE [dbo].[Athletes] ADD CONSTRAINT [FK_Athletes_Gender] FOREIGN KEY ([Gender]) REFERENCES [dbo].[Gender] ([Id])
GO
